###########
# Code Snippets for RShiny/Firearm Data
# Julie (Jules) Gilbert
# 2024-02-21
###########

library(tidyverse)
library(lubridate)
library(ggpubr)
library(reshape2)
library(gt)
library(leaflet)
library(tidygeocoder)
library(sf)

##
# dropbox data file location
ddf <- "C:/Users/juliegil/Dropbox (University of Michigan)/MICOM/WCHD/Firearm_Locks_Dashboard/"

################################################################################
### Mapping Gun Lock Distributions

gun_lock_data <- read.csv(paste0(ddf, "faux_data/Gun_lock_fake_data.csv"))

gun_lock_data$event_date <- as.POSIXct(gun_lock_data$event_date, format = "%m/%d/%Y")

gun_lock_data <- gun_lock_data %>% mutate(event_total_address = paste0(event_address, ", ", event_city, ", ", event_state, " ", event_zip))

gun_lock_data2 <- gun_lock_data %>% geocode(address = event_total_address, method = "osm")

gun_lock_data2 <- gun_lock_data2 %>% mutate(lat = case_when(event_address == "5561 Carpenter Road" ~ 42.207290, 
                                                            event_address == "315 S. Ford Road" ~ 42.238806, 
                                                            T ~ lat), 
                                            long = case_when(event_address == "5561 Carpenter Road" ~ -83.678893, 
                                                             event_address == "315 S. Ford Road" ~ -83.579393, 
                                                             T ~ long))

zipcode_boundaries <- paste0(ddf, "cb_2018_us_zcta510_500k/cb_2018_us_zcta510_500k.shp")

# convert it to shape file system (R)
zip_shp <- st_read(zipcode_boundaries, stringsAsFactors=FALSE)
zip_shp <- filter(zip_shp, substr(GEOID10, 1, 2) == "48")
zip_shp_ll <- st_transform(zip_shp, "+proj=longlat +ellps=WGS84 +datum=WGS84")
zip_shp_ll <- st_as_sf(zip_shp_ll)
zip_shp_ll <- st_cast(zip_shp_ll, to = c("POLYGON"))



leaflet() %>%
  addTiles() %>% setView(lng = -83.8473,
                         lat = 42.3076,
                         zoom = 10) %>%
  addPolygons(data = zip_shp_ll$geometry,
              color = "#000000", # you need to use hex colors
              fillOpacity = 0,
              weight = 1,
              smoothFactor = 0.2) %>% 
  addCircleMarkers(lng = gun_lock_data2$long, lat = gun_lock_data2$lat, 
                   stroke = FALSE, fillOpacity = 0.5, color = "#FFC857", 
                   radius = gun_lock_data2$number_distributed/2) %>% # add this as an option, to see "number distributed" as radius range
  addCircleMarkers(lng = gun_lock_data2$long, lat = gun_lock_data2$lat, 
                   popup = gun_lock_data2$event_total_address, 
                   stroke = FALSE, fillOpacity = 0.5, color = "#000000", 
                   radius = 4) 


################################################################################

# fill zip code areas by gun deaths and/or injuries
gun_death_data <- read.csv(paste0(ddf, "faux_data/Firearm_fake_data.csv"))
gun_injury_data <- read.csv(paste0(ddf, "faux_data/Firearm_injury_fake_data.csv"))

gun_injury_data$Date <- as.POSIXct(gun_injury_data$Date, format = "%m/%d/%Y")

gun_injury_data <- gun_injury_data %>% group_by(Incident.Zip, Syndrome) %>% summarize(count = length(Date))
gun_injury_data <- filter(gun_injury_data, Syndrome == "Firearm Injury - Intentional ")

zipcode_boundaries <- paste0(ddf, "cb_2018_us_zcta510_500k/cb_2018_us_zcta510_500k.shp")
zip_shp <- st_read(zipcode_boundaries, stringsAsFactors=FALSE)
zip_shp <- filter(zip_shp, substr(GEOID10, 1, 2) == "48")
zip_shp <- merge(zip_shp, gun_injury_data, by.x = c("GEOID10"), by.y = c("Incident.Zip"), all.x = TRUE)
zip_shp_ll <- st_transform(zip_shp, "+proj=longlat +ellps=WGS84 +datum=WGS84")
zip_shp_ll <- st_as_sf(zip_shp_ll)
zip_shp_ll <- st_cast(zip_shp_ll, to = c("POLYGON"))

# generate popup text
popup <- paste0(zip_shp_ll$GEOID10, "<br>", "Intentional Firearm Injuries = ", zip_shp_ll$count) # what the tooltip will show

# make a color scheme
pal2 <- colorBin("Blues", zip_shp_ll$count, 7, pretty = TRUE)

leaflet() %>%
  addTiles() %>% setView(lng = -83.8473,
                         lat = 42.3076,
                         zoom = 10) %>%
  addPolygons(data = zip_shp_ll$geometry,
              color = "#000000", # you need to use hex colors
              fillOpacity = 0,
              weight = 2,
              smoothFactor = 0.2) %>%
  addPolygons(data = zip_shp_ll$geometry,
              color = pal2(zip_shp_ll$count),
              fillOpacity = 0.7,
              weight = 1,
              smoothFactor = 0.2, 
              popup = popup)




##### line chart idea

gun_death_data <- read.csv(paste0(ddf, "faux_data/Firearm_fake_data.csv"))
gun_death_data$Date <- as.POSIXct(gun_death_data$Date, format = "%m/%d/%Y")
gun_death_data <- gun_death_data %>% group_by(Date, Manner_of_death) %>% summarize(count = length(Date))
colnames(gun_death_data) <- c("Date", "Type", "Count")

gun_injury_data <- read.csv(paste0(ddf, "faux_data/Firearm_injury_fake_data.csv"))
gun_injury_data$Date <- as.POSIXct(gun_injury_data$Date, format = "%m/%d/%Y")
gun_injury_data <- gun_injury_data %>% group_by(Date, Syndrome) %>% summarize(count = length(Date))
colnames(gun_injury_data) <- c("Date", "Type", "Count")

gun_data <- rbind(gun_death_data, gun_injury_data)
gun_data <- filter(gun_data, Type != "")


gun_lock_data <- read.csv(paste0(ddf, "faux_data/Gun_lock_fake_data.csv"))
gun_lock_data$event_date <- as.POSIXct(gun_lock_data$event_date, format = "%m/%d/%Y")


ggplot(gun_data, aes(x = Date, y = Count, group = Type, color = Type )) + 
  geom_line(linewidth = 1, alpha = 0.7) + 
  geom_vline(xintercept = unique(gun_lock_data$event_date), size = 1, linetype = "dashed") +
  theme_bw() + 
  labs(x = "", 
       y = "Count", 
       color = "")


##### possible option for counting lock distribution events AND looking at it against
##### injury events

gun_lock_data <- gun_lock_data %>% arrange(event_date) %>% mutate(event_count = 1, 
                                                                  cumulative_sum_lock_count = cumsum(number_distributed), 
                                                                  cumulative_event_count = cumsum(event_count))


ggplot() + 
  geom_bar(data = gun_data, aes(x = Date, y = Count*10, group = Type, fill = Type ), stat = "identity") +
  geom_line(data = gun_lock_data, aes(x = event_date, y = cumulative_sum_lock_count), color = "dodgerblue", linewidth = 1) + 
  geom_line(data = gun_lock_data, aes(x = event_date, y = cumulative_event_count), color = "black", linewidth = 1) + 
  theme_bw() + 
  scale_y_continuous(name = "Count", sec.axis = sec_axis( trans=~./10, name="Injury/Death Count")) +
  labs(x = "Date", 
       caption = "Black = Cumulative count of distribution events; Blue = Cumulative count of locks distributed")




######## looking at population data

pop_data <- read.csv(paste0(ddf, "ACSDP5Y2022.DP05_2024-02-09T103428/ACSDP5Y2022.DP05-Data.csv"))
pop_data2 <- pop_data[, c(1, 2, 3, 11, 13, 15, 17, 19, 21, 23, 25, 27, 29, 31, 33, 35)]
colnames(pop_data2) <- pop_data2[1, ]
pop_data2 <- pop_data2[-1, ]

colnames(pop_data2)
colnames(pop_data2) <- c("GEO", "AREANAME", "pop_Total", "pop_Under5", "pop_5to9", 
                         "pop_10to14", "pop_15to19", "pop_20to24", "pop_25to34", 
                         "pop_35to44", "pop_45to54", "pop_55to59", "pop_60to64", 
                         "pop_65to74", "pop_75to84", "pop_85andOver")


pop_data2 <- pop_data2 %>% separate(AREANAME, into = c("AREA", "ZIPCODE"), sep = " ")

total_pop_small <- pop_data2 %>% select(ZIPCODE, pop_Total)

gun_death_data <- read.csv(paste0(ddf, "faux_data/Firearm_fake_data.csv"))
gun_death_data$Date <- as.POSIXct(gun_death_data$Date, format = "%m/%d/%Y")

gun_death_data2 <- gun_death_data %>% group_by(Date, Death_Zip) %>% summarize(all_count = length(Manner_of_death))
#sum(gun_death_data2$all_count)

gun_death_data2 <- merge(gun_death_data2, total_pop_small, by.x = c("Death_Zip"), by.y = c("ZIPCODE"), all.x = TRUE, all.y = FALSE)
gun_death_data2 <- filter(gun_death_data2, !is.na(Date))


gun_death_data2 <- gun_death_data2 %>% mutate(death_per_10Kpop = (as.numeric(all_count) / as.numeric(pop_Total))*10000)

ggplot(gun_death_data2, aes(x = Date, y = death_per_10Kpop, fill = as.character(Death_Zip), group = Death_Zip)) + 
  geom_bar(stat = "identity") + 
  theme_bw() + 
  labs(x = "", 
       y = "Firearm Deaths per 10,000 Population", 
       fill = "Zip Codes")

#####
##### making little table view

randomly_chosen_event <- sample_n(gun_lock_data, 1)

before_event <- filter(gun_death_data2, Date < randomly_chosen_event$event_date)
before_event <- sum(before_event$all_count)
after_event <- filter(gun_death_data2, Date > randomly_chosen_event$event_date)
after_event <- sum(after_event$all_count)

event_count_prior_to_random <- nrow(filter(gun_lock_data, event_date < randomly_chosen_event$event_date))


table_df <- data.frame(event_count_prior_to_random, before_event, after_event)


  
table_df %>% gt() %>% 
  tab_header(
  title = "Firearm Death Events Before and After Gun Lock Distribution Event",
  subtitle = paste0("Distribution Event on ", unique(randomly_chosen_event$event_date))
) %>% cols_label(
  event_count_prior_to_random = html("Event Count Prior<br>To This Event"),
  before_event = html("Deaths Prior"),
  after_event = html("Deaths After")
) %>%  tab_style(
  style = cell_borders(
    sides = c("top", "right", "left", "bottom"),
    color = "black",
    weight = px(2.5),
    style = "solid"
  ),
  locations = cells_body()
) %>% tab_style(
  style = cell_text(
    color = "black",
    v_align = "middle"
  ),
  locations = cells_body()
) %>%  tab_style(
  style = cell_borders(
    sides = c("top", "right", "left", "bottom"),
    color = "black",
    weight = px(2.5),
    style = "solid"
  ),
  locations = cells_column_labels()
) %>% tab_style(
  style = cell_text(
    color = "black",
    v_align = "middle"
  ),
  locations = cells_column_labels()
) %>%  tab_style(
  style = cell_borders(
    sides = c("top", "right", "left", "bottom"),
    color = "black",
    weight = px(2.5),
    style = "solid"
  ),
  locations = cells_title()
) %>% cols_align(
  align = c("center"),
  columns = everything()
)


